pub enum CumulusDigestItem {
RelayParent(Hash),
CoreInfo(CoreInfo),
BlockBundleInfo(BlockBundleInfo),
UseFullCore,
}Expand description
Consensus header digests for Cumulus parachains.
Variants
RelayParent(Hash)
A digest item indicating the relay-parent a parachain block was built against.
CoreInfo(CoreInfo)
A digest item providing information about the core selected on the relay chain for this block.
BlockBundleInfo(BlockBundleInfo)
A digest item providing information about the position of the block in the bundle.
UseFullCore
A digest item informing the node that this block should be put alone onto a core.
In other words, the core should not be shared with other blocks.
Under certain conditions (mainly runtime misconfigurations) the digest is still set when there are muliple blocks per core. This is done to communicate to the collator that block production for this core should be stopped.
Implementations
Sourceimpl CumulusDigestItem
impl CumulusDigestItem
Sourcepub fn to_digest_item(&self) -> DigestItem
pub fn to_digest_item(&self) -> DigestItem
Encode this as a Substrate DigestItem.
Sourcepub fn find_core_info(digest: &Digest) -> Option<CoreInfo>
pub fn find_core_info(digest: &Digest) -> Option<CoreInfo>
Find CumulusDigestItem::CoreInfo in the given digest.
If there are multiple valid digests, this returns the value of the first one.
Sourcepub fn core_info_exists_at_max_once(digest: &Digest) -> CoreInfoExistsAtMaxOnce
pub fn core_info_exists_at_max_once(digest: &Digest) -> CoreInfoExistsAtMaxOnce
Returns the found CoreInfo and iff Self::CoreInfo exists at max once in the given
digest.
Sourcepub fn find_relay_block_identifier(
digest: &Digest,
) -> Option<RelayBlockIdentifier>
pub fn find_relay_block_identifier( digest: &Digest, ) -> Option<RelayBlockIdentifier>
Returns the RelayBlockIdentifier from the given digest.
The identifier corresponds to the relay parent used to build the parachain block.
Sourcepub fn find_block_bundle_info(digest: &Digest) -> Option<BlockBundleInfo>
pub fn find_block_bundle_info(digest: &Digest) -> Option<BlockBundleInfo>
Returns the BlockBundleInfo from the given digest.
Sourcepub fn contains_use_full_core(digest: &Digest) -> bool
pub fn contains_use_full_core(digest: &Digest) -> bool
Returns true if the given digest contains the Self::UseFullCore item.
Sourcepub fn is_last_block_in_core(digest: &Digest) -> Option<bool>
pub fn is_last_block_in_core(digest: &Digest) -> Option<bool>
Returns true if the given digest is from a block that is the last block in a core.
Checks the following conditions:
- Is
BlockBundleInfo::is_lastset to true? - Or is
Self::UseFullCoredigest present? - Or is
DigestItem::RuntimeEnvironmentUpdateddigest present?
If any of these conditions is true, this function will return true.
Returns None if the BlockBundleInfo digest is not present, which is interpreted as the
associated block is not using block bundling.