referrerpolicy=no-referrer-when-downgrade

KeyToIncludeInRelayProof

Trait KeyToIncludeInRelayProof 

pub trait KeyToIncludeInRelayProof<Block: BlockT>: Core<Block> {
    // Provided method
    fn keys_to_prove(
        &self,
        __runtime_api_at_param__: <Block as BlockT>::Hash,
    ) -> Result<RelayProofRequest, ApiError> { ... }
}
API for specifying which relay chain storage data to include in storage proofs.

This API allows parachains to request both top-level relay chain storage keys and child trie storage keys to be included in the relay chain state proof.

Provided Methods

fn keys_to_prove( &self, __runtime_api_at_param__: <Block as BlockT>::Hash, ) -> Result<RelayProofRequest, ApiError>

Returns relay chain storage proof requests.

The collator will include them in the relay chain proof that is passed alongside the parachain inherent into the runtime.